@@ -113,8 +113,7 @@ public final class CertificateVerifier
                 throw new CertificateVerificationException("The certificate is self-signed.");
             }
 
-            Set<X509Certificate> certSet = new HashSet<X509Certificate>();
-            certSet.addAll(additionalCerts);
+            Set<X509Certificate> certSet = new HashSet<X509Certificate>(additionalCerts);
 
             // Download extra certificates. However, each downloaded certificate can lead to
             // more extra certificates, e.g. with the file from PDFBOX-4091, which has
