@@ -116,7 +116,7 @@ public class CFFParser
         stringIndex = readStringIndexData(input);
         byte[][] globalSubrIndex = readIndexData(input);
 
-        List<CFFFont> fonts = new ArrayList<CFFFont>();
+        List<CFFFont> fonts = new ArrayList<CFFFont>(nameIndex.length);
         for (int i = 0; i < nameIndex.length; i++)
         {
             CFFFont font = parseFont(input, nameIndex[i], topDictIndex[i]);
@@ -275,7 +275,7 @@ public class CFFParser
             }
             else if (b0 == 30)
             {
-                entry.operands.add(readRealNumber(input, b0));
+                entry.operands.add(readRealNumber(input));
             }
             else if (b0 >= 32 && b0 <= 254)
             {
@@ -335,19 +335,18 @@ public class CFFParser
         }
     }
 
-    /**
-     * @param b0  
-     */
-    private static Double readRealNumber(CFFDataInput input, int b0) throws IOException
+    private static Double readRealNumber(CFFDataInput input) throws IOException
     {
         StringBuilder sb = new StringBuilder();
         boolean done = false;
         boolean exponentMissing = false;
         boolean hasExponent = false;
+        int[] nibbles = new int[2];
         while (!done)
         {
             int b = input.readUnsignedByte();
-            int[] nibbles = { b / 16, b % 16 };
+            nibbles[0] = b / 16;
+            nibbles[1] = b % 16;
             for (int nibble : nibbles)
             {
                 switch (nibble)
@@ -397,7 +396,8 @@ public class CFFParser
                     done = true;
                     break;
                 default:
-                    throw new IllegalArgumentException();
+                    // can only be a programming error because a nibble is between 0 and F 
+                    throw new IllegalArgumentException("illegal nibble " + nibble);
                 }
             }
         }
@@ -412,7 +412,14 @@ public class CFFParser
         {
             return 0d;
         }
-        return Double.valueOf(sb.toString());
+        try
+        {
+            return Double.valueOf(sb.toString());
+        }
+        catch (NumberFormatException ex)
+        {
+            throw new IOException(ex);
+        }
     }
 
     private CFFFont parseFont(CFFDataInput input, String name, byte[] topDictIndex) throws IOException
@@ -421,7 +428,7 @@ public class CFFParser
         CFFDataInput topDictInput = new CFFDataInput(topDictIndex);
         DictData topDict = readDictData(topDictInput);
 
-        // we dont't support synthetic fonts
+        // we don't support synthetic fonts
         DictData.Entry syntheticBaseEntry = topDict.getEntry("SyntheticBase");
         if (syntheticBaseEntry != null)
         {
@@ -433,11 +440,13 @@ public class CFFParser
         boolean isCIDFont = topDict.getEntry("ROS") != null;
         if (isCIDFont)
         {
-            font = new CFFCIDFont();
+            CFFCIDFont cffCIDFont = new CFFCIDFont();
             DictData.Entry rosEntry = topDict.getEntry("ROS");
-            ((CFFCIDFont) font).setRegistry(readString(rosEntry.getNumber(0).intValue()));
-            ((CFFCIDFont) font).setOrdering(readString(rosEntry.getNumber(1).intValue()));
-            ((CFFCIDFont) font).setSupplement(rosEntry.getNumber(2).intValue());
+            cffCIDFont.setRegistry(readString(rosEntry.getNumber(0).intValue()));
+            cffCIDFont.setOrdering(readString(rosEntry.getNumber(1).intValue()));
+            cffCIDFont.setSupplement(rosEntry.getNumber(2).intValue());
+
+            font = cffCIDFont;
         }
         else
         {
@@ -607,6 +616,10 @@ public class CFFParser
         int fontDictOffset = fdArrayEntry.getNumber(0).intValue();
         input.setPosition(fontDictOffset);
         byte[][] fdIndex = readIndexData(input);
+        if (fdIndex == null)
+        {
+            throw new IOException("Font dict index is missing for a CIDKeyed Font");
+        }
 
         List<Map<String, Object>> privateDictionaries = new LinkedList<Map<String, Object>>();
         List<Map<String, Object>> fontDictionaries = new LinkedList<Map<String, Object>>();
@@ -740,7 +753,7 @@ public class CFFParser
         }
     }
 
-    private String readString(int index) throws IOException
+    private String readString(int index)
     {
         if (index >= 0 && index <= 390)
         {
@@ -757,7 +770,7 @@ public class CFFParser
         }
     }
 
-    private String getString(DictData dict, String name) throws IOException
+    private String getString(DictData dict, String name)
     {
         DictData.Entry entry = dict.getEntry(name);
         return entry != null ? readString(entry.getNumber(0).intValue()) : null;
