@@ -40,7 +40,8 @@ public class Type1CharString
     private static final Log LOG = LogFactory.getLog(Type1CharString.class);
 
     private Type1CharStringReader font;
-    private final String fontName, glyphName;
+    private final String fontName;
+    private final String glyphName;
     private GeneralPath path = null;
     private int width = 0;
     private Point2D.Float leftSideBearing = null;
@@ -182,7 +183,7 @@ public class Type1CharString
         }
         else if ("vmoveto".equals(name))
         {
-            if (numbers.size() >= 1)
+            if (!numbers.isEmpty())
             {
                 if (isFlex)
                 {
@@ -197,7 +198,7 @@ public class Type1CharString
         }
         else if ("hmoveto".equals(name))
         {
-            if (numbers.size() >= 1)
+            if (!numbers.isEmpty())
             {
                 if (isFlex)
                 {
@@ -219,14 +220,14 @@ public class Type1CharString
         }
         else if ("hlineto".equals(name))
         {
-            if (numbers.size() >= 1)
+            if (!numbers.isEmpty())
             {
                 rlineTo(numbers.get(0), 0);
             }
         }
         else if ("vlineto".equals(name))
         {
-            if (numbers.size() >= 1)
+            if (!numbers.isEmpty())
             {
                 rlineTo(0, numbers.get(0));
             }
@@ -293,7 +294,7 @@ public class Type1CharString
         }
         else if ("callothersubr".equals(name))
         {
-            if (numbers.size() >= 1)
+            if (!numbers.isEmpty())
             {
                 callothersubr(numbers.get(0).intValue());
             }
