@@ -52,6 +52,9 @@ public class CMap
     // Unicode mappings
     private final Map<Integer,String> charToUnicode = new HashMap<Integer,String>();
 
+    // inverted map
+    Map <String, byte[]> unicodeToByteCodes = new HashMap<String, byte[]>();
+
     // CID mappings
     private final Map<Integer,Integer> codeToCid = new HashMap<Integer,Integer>();
     private final List<CIDRange> codeToCidRanges = new ArrayList<CIDRange>();
@@ -109,6 +112,7 @@ public class CMap
     {
         byte[] bytes = new byte[maxCodeLength];
         in.read(bytes,0,minCodeLength);
+        in.mark(maxCodeLength);
         for (int i = minCodeLength-1; i < maxCodeLength; i++)
         {
             final int byteCount = i+1;
@@ -130,7 +134,17 @@ public class CMap
             seq += String.format("0x%02X (%04o) ", bytes[i], bytes[i]);
         }
         LOG.warn("Invalid character code sequence " + seq + "in CMap " + cmapName);
-        return 0;
+        // PDFBOX-4811 reposition to where we were after initial read
+        if (in.markSupported())
+        {
+            in.reset();
+        }
+        else
+        {
+            LOG.warn("mark() and reset() not supported, " + (maxCodeLength - 1) +
+                     " bytes have been skipped");
+        }
+        return toInt(bytes, minCodeLength); // Adobe Reader behavior
     }
 
     /**
@@ -197,6 +211,7 @@ public class CMap
      */
     void addCharMapping(byte[] codes, String unicode)
     {
+        unicodeToByteCodes.put(unicode, codes.clone()); // clone needed, bytes is modified later
         int code = getCodeFromArray(codes, 0, codes.length);
         charToUnicode.put(code, unicode);
 
@@ -207,6 +222,17 @@ public class CMap
         }
     }
 
+    /**
+     * Get the code bytes for an unicode string.
+     *
+     * @param unicode
+     * @return the code bytes or null if there is none.
+     */
+    public byte[] getCodesFromUnicode(String unicode)
+    {
+        return unicodeToByteCodes.get(unicode);
+    }
+
     /**
      * This will add a CID mapping.
      *
@@ -266,6 +292,9 @@ public class CMap
         charToUnicode.putAll(cmap.charToUnicode);
         codeToCid.putAll(cmap.codeToCid);
         codeToCidRanges.addAll(cmap.codeToCidRanges);
+
+        // unicodeToByteCodes should be filled too, but this isn't possible in 2.0.*
+        // because we don't know the code length
     }
 
     /**
