@@ -37,8 +37,8 @@ public class CmapSubtable implements CmapLookup
 {
     private static final Log LOG = LogFactory.getLog(CmapSubtable.class);
 
-    private static final long LEAD_OFFSET = 0xD800 - (0x10000 >> 10);
-    private static final long SURROGATE_OFFSET = 0x10000 - (0xD800 << 10) - 0xDC00;
+    private static final long LEAD_OFFSET = 0xD800l - (0x10000 >> 10);
+    private static final long SURROGATE_OFFSET = 0x10000l - (0xD800 << 10) - 0xDC00;
 
     private int platformId;
     private int platformEncodingId;
@@ -640,6 +640,7 @@ public class CmapSubtable implements CmapLookup
      * @deprecated the mapping may be ambiguous, see {@link #getCharCodes(int)}. The first mapped value is returned by
      * default.
      */
+    @Deprecated
     public Integer getCharacterCode(int gid)
     {
         int code = getCharCode(gid);
