@@ -272,7 +272,7 @@ public final class TTFSubsetter
     {
         return nr.getPlatformId() == NameRecord.PLATFORM_WINDOWS
                 && nr.getPlatformEncodingId() == NameRecord.ENCODING_WINDOWS_UNICODE_BMP
-                && nr.getLanguageId() == NameRecord.LANGUGAE_WINDOWS_EN_US
+                && nr.getLanguageId() == NameRecord.LANGUAGE_WINDOWS_EN_US
                 && nr.getNameId() >= 0 && nr.getNameId() < 7;
     }
 
