@@ -1559,8 +1559,7 @@ public class COSDictionary extends COSBase implements COSUpdateInfo
         objs.add(base);
         if (base instanceof COSDictionary)
         {
-            StringBuilder sb = new StringBuilder();
-            sb.append("COSDictionary{");
+            StringBuilder sb = new StringBuilder("COSDictionary{");
             for (Map.Entry<COSName, COSBase> x : ((COSDictionary) base).entrySet())
             {
                 sb.append(x.getKey());
@@ -1580,9 +1579,8 @@ public class COSDictionary extends COSBase implements COSUpdateInfo
         }
         if (base instanceof COSArray)
         {
-            StringBuilder sb = new StringBuilder();
-            sb.append("COSArray{");
-            for (COSBase x : ((COSArray) base).toList())
+            StringBuilder sb = new StringBuilder("COSArray{");
+            for (COSBase x : ((COSArray) base))
             {
                 sb.append(getDictionaryString(x, objs));
                 sb.append(";");
