@@ -16,7 +16,6 @@
  */
 package org.apache.pdfbox.pdfparser;
 
-import java.io.ByteArrayInputStream;
 import java.io.ByteArrayOutputStream;
 import java.io.IOException;
 import java.util.ArrayList;
@@ -34,6 +33,7 @@ import org.apache.pdfbox.cos.COSNull;
 import org.apache.pdfbox.cos.COSNumber;
 import org.apache.pdfbox.cos.COSObject;
 import org.apache.pdfbox.cos.COSStream;
+import org.apache.pdfbox.io.RandomAccessBuffer;
 import org.apache.pdfbox.pdmodel.common.PDStream;
 
 /**
@@ -100,7 +100,7 @@ public class PDFStreamParser extends BaseParser
      */
     public PDFStreamParser(byte[] bytes) throws IOException
     {
-        super(new InputStreamSource(new ByteArrayInputStream(bytes)));
+        super(new RandomAccessSource(new RandomAccessBuffer(bytes)));
     }
 
     /**
@@ -137,19 +137,15 @@ public class PDFStreamParser extends BaseParser
      */
     public Object parseNextToken() throws IOException
     {
-        Object retval;
-
         skipSpaces();
-        int nextByte = seqSource.peek();
-        if( ((byte)nextByte) == -1 )
+        if (seqSource.isEOF())
         {
             return null;
         }
-        char c = (char)nextByte;
+        char c = (char) seqSource.peek();
         switch (c)
         {
             case '<':
-            {
                 // pull off first left bracket
                 int leftBracket = seqSource.read();
 
@@ -161,74 +157,57 @@ public class PDFStreamParser extends BaseParser
 
                 if (c == '<')
                 {
-                    retval = parseCOSDictionary();
+                    return parseCOSDictionary();
                 }
                 else
                 {
-                    retval = parseCOSString();
+                    return parseCOSString();
                 }
-                break;
-            }
             case '[':
-            {
                 // array
-                retval = parseCOSArray();
-                break;
-            }
+                return parseCOSArray();
             case '(':
                 // string
-                retval = parseCOSString();
-                break;
+                return parseCOSString();
             case '/':
                 // name
-                retval = parseCOSName();
-                break;
+                return parseCOSName();
             case 'n':   
-            {
                 // null
                 String nullString = readString();
                 if( nullString.equals( "null") )
                 {
-                    retval = COSNull.NULL;
+                    return COSNull.NULL;
                 }
                 else
                 {
-                    retval = Operator.getOperator(nullString);
+                    return Operator.getOperator(nullString);
                 }
-                break;
-            }
             case 't':
             case 'f':
-            {
                 String next = readString();
                 if( next.equals( "true" ) )
                 {
-                    retval = COSBoolean.TRUE;
-                    break;
+                    return COSBoolean.TRUE;
                 }
                 else if( next.equals( "false" ) )
                 {
-                    retval = COSBoolean.FALSE;
+                    return COSBoolean.FALSE;
                 }
                 else
                 {
-                    retval = Operator.getOperator(next);
+                    return Operator.getOperator(next);
                 }
-                break;
-            }
             case 'R':
-            {
                 String line = readString();
                 if( line.equals( "R" ) )
                 {
-                    retval = new COSObject( null );
+                    return new COSObject(null);
                 }
                 else
                 {
-                    retval = Operator.getOperator(line);
+                    return Operator.getOperator(line);
                 }
-                break;
-            }
             case '0':
             case '1':
             case '2':
@@ -242,7 +221,6 @@ public class PDFStreamParser extends BaseParser
             case '-':
             case '+':
             case '.':
-            {
                 /* We will be filling buf with the rest of the number.  Only
                  * allow 1 "." and "-" and "+" at start of number. */
                 StringBuilder buf = new StringBuilder();
@@ -270,39 +248,35 @@ public class PDFStreamParser extends BaseParser
                         dotNotRead = false;
                     }
                 }
-                retval = COSNumber.get( buf.toString() );
-                break;
-            }
+                return COSNumber.get(buf.toString());
             case 'B':
-            {
-                String next = readString();
-                retval = Operator.getOperator(next);
-            if (next.equals(OperatorName.BEGIN_INLINE_IMAGE))
+                String nextOperator = readString();
+                Operator beginImageOP = Operator.getOperator(nextOperator);
+                if (nextOperator.equals(OperatorName.BEGIN_INLINE_IMAGE))
                 {
-                    Operator beginImageOP = (Operator)retval;
                     COSDictionary imageParams = new COSDictionary();
-                    beginImageOP.setImageParameters( imageParams );
+                    beginImageOP.setImageParameters(imageParams);
                     Object nextToken = null;
-                    while( (nextToken = parseNextToken()) instanceof COSName )
+                    while ((nextToken = parseNextToken()) instanceof COSName)
                     {
                         Object value = parseNextToken();
-                        imageParams.setItem( (COSName)nextToken, (COSBase)value );
+                        imageParams.setItem((COSName) nextToken, (COSBase) value);
                     }
-                    //final token will be the image data, maybe??
+                    // final token will be the image data, maybe??
                     if (nextToken instanceof Operator)
                     {
                         Operator imageData = (Operator) nextToken;
-                        if (imageData.getImageData() == null || imageData.getImageData().length == 0)
+                        if (imageData.getImageData() == null
+                                || imageData.getImageData().length == 0)
                         {
-                            LOG.warn("empty inline image at stream offset " + seqSource.getPosition());
+                            LOG.warn("empty inline image at stream offset "
+                                    + seqSource.getPosition());
                         }
                         beginImageOP.setImageData(imageData.getImageData());
                     }
                 }
-                break;
-            }
+                return beginImageOP;
             case 'I':
-            {
                 //Special case for ID operator
                 String id = Character.toString((char) seqSource.read()) + (char) seqSource.read();
                 if (!id.equals(OperatorName.BEGIN_INLINE_IMAGE_DATA))
@@ -333,37 +307,26 @@ public class PDFStreamParser extends BaseParser
                     currentByte = seqSource.read();
                 }
                 // the EI operator isn't unread, as it won't be processed anyway
-            retval = Operator.getOperator(OperatorName.BEGIN_INLINE_IMAGE_DATA);
+                Operator beginImageDataOP = Operator
+                        .getOperator(OperatorName.BEGIN_INLINE_IMAGE_DATA);
                 // save the image data to the operator, so that it can be accessed later
-                ((Operator)retval).setImageData( imageData.toByteArray() );
-                break;
-            }
+                beginImageDataOP.setImageData(imageData.toByteArray());
+                return beginImageDataOP;
             case ']':
-            {
                 // some ']' around without its previous '['
                 // this means a PDF is somewhat corrupt but we will continue to parse.
                 seqSource.read();
-                
                 // must be a better solution than null...
-                retval = COSNull.NULL;  
-                break;
-            }
+                return COSNull.NULL;
             default:
-            {
-                //we must be an operator
+                // we must be an operator
                 String operator = readOperator();
-                if( operator.trim().length() == 0 )
+                if (operator.trim().length() > 0)
                 {
-                    //we have a corrupt stream, stop reading here
-                    retval = null;
+                    return Operator.getOperator(operator);
                 }
-                else
-                {
-                    retval = Operator.getOperator(operator);
-                }
-            }
         }
-        return retval;
+        return null;
     }
 
     /**
