@@ -258,6 +258,39 @@ public class COSWriter implements ICOSVisitor, Closeable
         incrementalUpdate = true;
     }
 
+    /**
+     * Constructor for incremental updates with a list of objects to write. This allows to
+     * include objects even if there is no path of objects that have
+     * {@link COSUpdateInfo#isNeedToBeUpdated()} set so the incremental update gets smaller. Only
+     * dictionaries are supported; if you need to update other objects classes, then add their
+     * parent dictionary.
+     *
+     * @param outputStream output stream where the new PDF data will be written. It will be closed
+     * when this object is closed.
+     * @param inputData random access read containing source PDF data.
+     * @param objectsToWrite objects that <b>must</b> be part of the incremental saving.
+     * @throws IOException if something went wrong
+     */
+    public COSWriter(OutputStream outputStream, RandomAccessRead inputData,
+            Set<COSDictionary> objectsToWrite) throws IOException
+    {
+        // Implementation notes / summary of April 2019 comments in PDFBOX-45:
+        // we allow only COSDictionary in objectsToWrite because other types, 
+        // especially COSArray, are written directly. If we'd allow them with the current
+        // COSWriter implementation, they would be written twice,
+        // once directly and once indirectly as orphan.
+        // One could improve visitFromArray and visitFromDictionary (see commit 1856891)
+        // to handle arrays like dictionaries so that arrays are written indirectly,
+        // but this produces very inefficient files.
+        // If there is ever a real need to update arrays, then a future implementation could
+        // recommit change 1856891 (also needs to move the byteRange position detection code)
+        // and also set isDirect in arrays to true by default, to avoid inefficient files.
+        // COSArray.setDirect(true) is called at some places in the current implementation for
+        // documentational purposes only.
+        this(outputStream, inputData);
+        this.objectsToWrite.addAll(objectsToWrite);
+    }
+
     private void prepareIncrement(PDDocument doc)
     {
       try
@@ -488,8 +521,7 @@ public class COSWriter implements ICOSVisitor, Closeable
                 cosBase = keyObject.get(cosObjectKey);
             }
             if (actual != null && objectKeys.containsKey(actual) 
-                    && object instanceof COSUpdateInfo && !((COSUpdateInfo)object).isNeedToBeUpdated() 
-                    && cosBase instanceof COSUpdateInfo && !((COSUpdateInfo)cosBase).isNeedToBeUpdated() )
+                    && !isNeedToBeUpdated(object) && !isNeedToBeUpdated(cosBase))
             {
                 return;
             }
@@ -502,6 +534,20 @@ public class COSWriter implements ICOSVisitor, Closeable
         }
     }
 
+    /**
+     * Convenience method, so that we get false for types that can't be updated.
+     * @param base
+     * @return 
+     */
+    private boolean isNeedToBeUpdated(COSBase base)
+    {
+        if (base instanceof COSUpdateInfo)
+        {
+            return ((COSUpdateInfo) base).isNeedToBeUpdated();
+        }
+        return false;
+    }
+
     /**
      * This will write a COS object.
      *
@@ -721,7 +767,7 @@ public class COSWriter implements ICOSVisitor, Closeable
         byteOut.flush();
         incrementPart = byteOut.toByteArray();
 
-        // overwrite the ByteRange in the buffer
+        // overwrite the reserve ByteRange in the buffer
         byte[] byteRangeBytes = byteRange.getBytes(Charsets.ISO_8859_1);
         for (int i = 0; i < byteRangeLength; i++)
         {
@@ -853,9 +899,9 @@ public class COSWriter implements ICOSVisitor, Closeable
         long count = 1;
 
         List<Long> list = new ArrayList<Long>();
-        for( Object object : xRefEntriesList )
+        for (COSWriterXRefEntry object : xRefEntriesList)
         {
-            long nr = (int) ((COSWriterXRefEntry) object).getKey().getNumber();
+            long nr = object.getKey().getNumber();
             if (nr == last + 1)
             {
                 ++count;
