@@ -509,6 +509,12 @@ public abstract class SecurityHandler
         {
            encryptData(objNum, genNum, encryptedStream, output, true /* decrypt */);
         }
+        catch (IOException ex)
+        {
+            LOG.error(ex.getClass().getSimpleName() + " thrown when decrypting object " +
+                    objNum + " " + genNum + " obj");
+            throw ex;
+        }
         finally
         {
             output.close();
