@@ -74,7 +74,7 @@ public class FDFPage implements COSObjectable
         COSArray array = (COSArray) page.getDictionaryObject(COSName.TEMPLATES);
         if (array != null)
         {
-            List<FDFTemplate> objects = new ArrayList<FDFTemplate>();
+            List<FDFTemplate> objects = new ArrayList<FDFTemplate>(array.size());
             for (int i = 0; i < array.size(); i++)
             {
                 objects.add(new FDFTemplate((COSDictionary) array.getObject(i)));
