@@ -36,6 +36,7 @@ import org.apache.fontbox.FontBoxFont;
 import org.apache.fontbox.cff.CFFCIDFont;
 import org.apache.fontbox.cff.CFFFont;
 import org.apache.fontbox.ttf.NamingTable;
+import org.apache.fontbox.ttf.OS2WindowsMetricsTable;
 import org.apache.fontbox.ttf.OTFParser;
 import org.apache.fontbox.ttf.OpenTypeFont;
 import org.apache.fontbox.ttf.TTFParser;
@@ -116,8 +117,10 @@ final class FileSystemFontProvider extends FontProvider
          * 
          */
         @Override
-        public FontBoxFont getFont()
+        public synchronized FontBoxFont getFont()
         {
+            // synchronized to avoid race condition on cache access,
+            // which could result in an unreferenced but open font
             FontBoxFont cached = parent.cache.getFont(this);
             if (cached != null)
             {
@@ -195,10 +198,6 @@ final class FileSystemFontProvider extends FontProvider
                 }
                 return ttf;
             }
-            catch (NullPointerException e) // TTF parser is buggy
-            {
-                LOG.error("Could not load font file: " + file, e);
-            }
             catch (IOException e)
             {
                 LOG.error("Could not load font file: " + file, e);
@@ -214,7 +213,16 @@ final class FileSystemFontProvider extends FontProvider
                 // ttc not closed here because it is needed later when ttf is accessed,
                 // e.g. rendering PDF with non-embedded font which is in ttc file in our font directory
                 TrueTypeCollection ttc = new TrueTypeCollection(file);
-                TrueTypeFont ttf = ttc.getFontByName(postScriptName);
+                TrueTypeFont ttf = null;
+                try
+                {
+                    ttf = ttc.getFontByName(postScriptName);
+                }
+                catch (IOException ex)
+                {
+                    ttc.close();
+                    throw ex;
+                }
                 if (ttf == null)
                 {
                     ttc.close();
@@ -233,7 +241,31 @@ final class FileSystemFontProvider extends FontProvider
         {
             try
             {
-                // todo JH: we don't yet support loading CFF fonts from OTC collections 
+                if (file.getName().toLowerCase().endsWith(".ttc"))
+                {
+                    @SuppressWarnings("squid:S2095")
+                    // ttc not closed here because it is needed later when ttf is accessed,
+                    // e.g. rendering PDF with non-embedded font which is in ttc file in our font directory
+                    TrueTypeCollection ttc = new TrueTypeCollection(file);
+                    TrueTypeFont ttf = null;
+                    try
+                    {
+                        ttf = ttc.getFontByName(postScriptName);
+                    }
+                    catch (IOException ex)
+                    {
+                        LOG.error(ex.getMessage(), ex);
+                        ttc.close();
+                        return null;
+                    }
+                    if (ttf == null)
+                    {
+                        ttc.close();
+                        throw new IOException("Font " + postScriptName + " not found in " + file);
+                    }
+                    return (OpenTypeFont) ttf;
+                }
+
                 OTFParser parser = new OTFParser(false, true);
                 OpenTypeFont otf = parser.parse(file);
 
@@ -301,9 +333,9 @@ final class FileSystemFontProvider extends FontProvider
             }
 
             // scan the local system for font files
-            List<File> files = new ArrayList<File>();
             FontFileFinder fontFileFinder = new FontFileFinder();
             List<URI> fonts = fontFileFinder.find();
+            List<File> files = new ArrayList<File>(fonts.size());
             for (URI font : fonts)
             {
                 files.add(new File(font));
@@ -341,17 +373,16 @@ final class FileSystemFontProvider extends FontProvider
         {
             try
             {
-                if (file.getPath().toLowerCase().endsWith(".ttf") ||
-                        file.getPath().toLowerCase().endsWith(".otf"))
+                String filePath = file.getPath().toLowerCase();
+                if (filePath.endsWith(".ttf") || filePath.endsWith(".otf"))
                 {
                     addTrueTypeFont(file);
                 }
-                else if (file.getPath().toLowerCase().endsWith(".ttc") ||
-                        file.getPath().toLowerCase().endsWith(".otc"))
+                else if (filePath.endsWith(".ttc") || filePath.endsWith(".otc"))
                 {
                     addTrueTypeCollection(file);
                 }
-                else if (file.getPath().toLowerCase().endsWith(".pfb"))
+                else if (filePath.endsWith(".pfb"))
                 {
                     addType1Font(file);
                 }
@@ -462,7 +493,7 @@ final class FileSystemFontProvider extends FontProvider
      */
     private List<FSFontInfo> loadDiskCache(List<File> files)
     {
-        Set<String> pending = new HashSet<String>();
+        Set<String> pending = new HashSet<String>(files.size());
         for (File file : files)
         {
             pending.add(file.getAbsolutePath());
@@ -594,10 +625,6 @@ final class FileSystemFontProvider extends FontProvider
                 }
             });
         }
-        catch (NullPointerException e) // TTF parser is buggy
-        {
-            LOG.error("Could not load font file: " + ttcFile, e);
-        }
         catch (IOException e)
         {
             LOG.error("Could not load font file: " + ttcFile, e);
@@ -631,10 +658,6 @@ final class FileSystemFontProvider extends FontProvider
                 addTrueTypeFontImpl(ttf, ttfFile);
             }
         }
-        catch (NullPointerException e) // TTF parser is buggy
-        {
-            LOG.error("Could not load font file: " + ttfFile, e);
-        }
         catch (IOException e)
         {
             LOG.error("Could not load font file: " + ttfFile, e);
@@ -669,14 +692,15 @@ final class FileSystemFontProvider extends FontProvider
                 int ulCodePageRange1 = 0;
                 int ulCodePageRange2 = 0;
                 byte[] panose = null;
+                OS2WindowsMetricsTable os2WindowsMetricsTable = ttf.getOS2Windows();
                 // Apple's AAT fonts don't have an OS/2 table
-                if (ttf.getOS2Windows() != null)
+                if (os2WindowsMetricsTable != null)
                 {
-                    sFamilyClass = ttf.getOS2Windows().getFamilyClass();
-                    usWeightClass = ttf.getOS2Windows().getWeightClass();
-                    ulCodePageRange1 = (int)ttf.getOS2Windows().getCodePageRange1();
-                    ulCodePageRange2 = (int)ttf.getOS2Windows().getCodePageRange2();
-                    panose = ttf.getOS2Windows().getPanose();
+                    sFamilyClass = os2WindowsMetricsTable.getFamilyClass();
+                    usWeightClass = os2WindowsMetricsTable.getWeightClass();
+                    ulCodePageRange1 = (int) os2WindowsMetricsTable.getCodePageRange1();
+                    ulCodePageRange2 = (int) os2WindowsMetricsTable.getCodePageRange2();
+                    panose = os2WindowsMetricsTable.getPanose();
                 }
 
                 String format;
