@@ -16,6 +16,7 @@
  */
 package org.apache.pdfbox.pdmodel.font;
 
+import java.io.BufferedInputStream;
 import java.io.IOException;
 import java.io.InputStream;
 import java.util.ArrayList;
@@ -28,6 +29,8 @@ import java.util.List;
 import java.util.Map;
 import java.util.PriorityQueue;
 import java.util.Set;
+import org.apache.commons.logging.Log;
+import org.apache.commons.logging.LogFactory;
 import org.apache.fontbox.FontBoxFont;
 import org.apache.fontbox.ttf.OpenTypeFont;
 import org.apache.fontbox.ttf.TTFParser;
@@ -41,6 +44,8 @@ import org.apache.fontbox.type1.Type1Font;
  */
 final class FontMapperImpl implements FontMapper
 {
+    private static final Log LOG = LogFactory.getLog(FontMapperImpl.class);
+
     private static final FontCache fontCache = new FontCache(); // todo: static cache isn't ideal
     private FontProvider fontProvider;
     private Map<String, FontInfo> fontInfoByName;
@@ -53,44 +58,50 @@ final class FontMapperImpl implements FontMapper
     {
         // substitutes for standard 14 fonts
         substitutes.put("Courier",
-                Arrays.asList("CourierNew", "CourierNewPSMT", "LiberationMono", "NimbusMonL-Regu"));
+                new ArrayList<String>(Arrays.asList("CourierNew", "CourierNewPSMT", "LiberationMono",
+                        "NimbusMonL-Regu")));
         substitutes.put("Courier-Bold",
-                Arrays.asList("CourierNewPS-BoldMT", "CourierNew-Bold", "LiberationMono-Bold",
-                        "NimbusMonL-Bold"));
+                new ArrayList<String>(Arrays.asList("CourierNewPS-BoldMT", "CourierNew-Bold",
+                        "LiberationMono-Bold", "NimbusMonL-Bold")));
         substitutes.put("Courier-Oblique",
-                Arrays.asList("CourierNewPS-ItalicMT","CourierNew-Italic",
-                        "LiberationMono-Italic", "NimbusMonL-ReguObli"));
+                new ArrayList<String>(Arrays.asList("CourierNewPS-ItalicMT","CourierNew-Italic",
+                        "LiberationMono-Italic", "NimbusMonL-ReguObli")));
         substitutes.put("Courier-BoldOblique",
-                Arrays.asList("CourierNewPS-BoldItalicMT","CourierNew-BoldItalic",
-                        "LiberationMono-BoldItalic", "NimbusMonL-BoldObli"));
+                new ArrayList<String>(Arrays.asList("CourierNewPS-BoldItalicMT", 
+                        "CourierNew-BoldItalic", "LiberationMono-BoldItalic",
+                        "NimbusMonL-BoldObli")));
         substitutes.put("Helvetica",
-                Arrays.asList("ArialMT", "Arial", "LiberationSans", "NimbusSanL-Regu"));
+                new ArrayList<String>(Arrays.asList("ArialMT", "Arial", "LiberationSans", 
+                        "NimbusSanL-Regu")));
         substitutes.put("Helvetica-Bold",
-                Arrays.asList("Arial-BoldMT", "Arial-Bold", "LiberationSans-Bold",
-                        "NimbusSanL-Bold"));
+                new ArrayList<String>(Arrays.asList("Arial-BoldMT", "Arial-Bold",
+                        "LiberationSans-Bold", "NimbusSanL-Bold")));
         substitutes.put("Helvetica-Oblique",
-                Arrays.asList("Arial-ItalicMT", "Arial-Italic", "Helvetica-Italic",
-                        "LiberationSans-Italic", "NimbusSanL-ReguItal"));
+                new ArrayList<String>(Arrays.asList("Arial-ItalicMT", "Arial-Italic",
+                        "Helvetica-Italic", "LiberationSans-Italic", "NimbusSanL-ReguItal")));
         substitutes.put("Helvetica-BoldOblique",
-                Arrays.asList("Arial-BoldItalicMT", "Helvetica-BoldItalic",
-                        "LiberationSans-BoldItalic", "NimbusSanL-BoldItal"));
+                new ArrayList<String>(Arrays.asList("Arial-BoldItalicMT", "Helvetica-BoldItalic",
+                        "LiberationSans-BoldItalic", "NimbusSanL-BoldItal")));
         substitutes.put("Times-Roman",
-                Arrays.asList("TimesNewRomanPSMT", "TimesNewRoman", "TimesNewRomanPS",
-                        "LiberationSerif", "NimbusRomNo9L-Regu"));
+                new ArrayList<String>(Arrays.asList("TimesNewRomanPSMT", "TimesNewRoman",
+                        "TimesNewRomanPS", "LiberationSerif", "NimbusRomNo9L-Regu")));
         substitutes.put("Times-Bold",
-                Arrays.asList("TimesNewRomanPS-BoldMT", "TimesNewRomanPS-Bold",
+                new ArrayList<String>(Arrays.asList("TimesNewRomanPS-BoldMT", "TimesNewRomanPS-Bold",
                         "TimesNewRoman-Bold", "LiberationSerif-Bold",
-                        "NimbusRomNo9L-Medi"));
+                        "NimbusRomNo9L-Medi")));
         substitutes.put("Times-Italic",
-                Arrays.asList("TimesNewRomanPS-ItalicMT", "TimesNewRomanPS-Italic",
-                        "TimesNewRoman-Italic", "LiberationSerif-Italic",
-                        "NimbusRomNo9L-ReguItal"));
+                new ArrayList<String>(Arrays.asList("TimesNewRomanPS-ItalicMT", 
+                        "TimesNewRomanPS-Italic", "TimesNewRoman-Italic", "LiberationSerif-Italic",
+                        "NimbusRomNo9L-ReguItal")));
         substitutes.put("Times-BoldItalic",
-                Arrays.asList("TimesNewRomanPS-BoldItalicMT", "TimesNewRomanPS-BoldItalic",
-                        "TimesNewRoman-BoldItalic", "LiberationSerif-BoldItalic",
-                        "NimbusRomNo9L-MediItal"));
-        substitutes.put("Symbol", Arrays.asList("Symbol", "SymbolMT", "StandardSymL"));
-        substitutes.put("ZapfDingbats", Arrays.asList("ZapfDingbatsITC", "Dingbats", "MS-Gothic"));
+                new ArrayList<String>(Arrays.asList("TimesNewRomanPS-BoldItalicMT", 
+                        "TimesNewRomanPS-BoldItalic", "TimesNewRoman-BoldItalic",
+                        "LiberationSerif-BoldItalic", "NimbusRomNo9L-MediItal")));
+        substitutes.put("Symbol", 
+                new ArrayList<String>(Arrays.asList("Symbol", "SymbolMT", "StandardSymL")));
+        substitutes.put("ZapfDingbats", new ArrayList<String>(
+                Arrays.asList("ZapfDingbatsITCbyBT-Regular", "ZapfDingbatsITC", "Dingbats", 
+                        "MS-Gothic")));
 
         // Acrobat also uses alternative names for Standard 14 fonts, which we map to those above
         // these include names such as "Arial" and "TimesNewRoman"
@@ -108,11 +119,12 @@ final class FontMapperImpl implements FontMapper
         try
         {
             String ttfName = "/org/apache/pdfbox/resources/ttf/LiberationSans-Regular.ttf";
-            InputStream ttfStream = FontMapper.class.getResourceAsStream(ttfName);
-            if (ttfStream == null)
+            InputStream resourceAsStream = FontMapper.class.getResourceAsStream(ttfName);
+            if (resourceAsStream == null)
             {
-                throw new IOException("Error loading resource: " + ttfName);
+                throw new IOException("resource '" + ttfName + "' not found");
             }
+            InputStream ttfStream = new BufferedInputStream(resourceAsStream);
             TTFParser ttfParser = new TTFParser();
             lastResortFont = ttfParser.parse(ttfStream);
         }
@@ -467,6 +479,10 @@ final class FontMapperImpl implements FontMapper
         FontInfo info = fontInfoByName.get(postScriptName);
         if (info != null && info.getFormat() == format)
         {
+            if (LOG.isDebugEnabled())
+            {
+                LOG.debug(String.format("getFont('%s','%s') returns %s", format, postScriptName, info));
+            }
             return info;
         }
         return null;
@@ -513,6 +529,10 @@ final class FontMapperImpl implements FontMapper
                 FontMatch bestMatch = queue.poll();
                 if (bestMatch != null)
                 {
+                    if (LOG.isDebugEnabled())
+                    {
+                        LOG.debug("Best match for '" + baseFont + "': " + bestMatch.info);
+                    }
                     FontBoxFont font = bestMatch.info.getFont();
                     if (font instanceof OpenTypeFont)
                     {
@@ -667,6 +687,11 @@ final class FontMapperImpl implements FontMapper
             long CHINESE_TRADITIONAL = 1 << 20;
             long KOREAN_JOHAB = 1 << 21;
             
+            if ("MalgunGothic-Semilight".equals(info.getPostScriptName()))
+            {
+                // PDFBOX-4793 and PDF.js 10699: This font has only Korean, but has bits 17-21 set.
+                codePageRange &= ~(JIS_JAPAN | CHINESE_SIMPLIFIED | CHINESE_TRADITIONAL);
+            }
             if (cidSystemInfo.getOrdering().equals("GB1") &&
                     (codePageRange & CHINESE_SIMPLIFIED) == CHINESE_SIMPLIFIED)
             {
@@ -685,8 +710,8 @@ final class FontMapperImpl implements FontMapper
             else
             {
                 return cidSystemInfo.getOrdering().equals("Korea1") &&
-                        (codePageRange & KOREAN_WANSUNG) == KOREAN_WANSUNG ||
-                        (codePageRange & KOREAN_JOHAB) == KOREAN_JOHAB;
+                        ((codePageRange & KOREAN_WANSUNG) == KOREAN_WANSUNG ||
+                         (codePageRange & KOREAN_JOHAB) == KOREAN_JOHAB);
             }
         }
     }
