@@ -174,15 +174,7 @@ public class PDType1Font extends PDSimpleFont
      */
     public PDType1Font(PDDocument doc, InputStream pfbIn) throws IOException
     {
-        PDType1FontEmbedder embedder = new PDType1FontEmbedder(doc, dict, pfbIn, null);
-        encoding = embedder.getFontEncoding();
-        glyphList = embedder.getGlyphList();
-        type1font = embedder.getType1Font();
-        genericFont = embedder.getType1Font();
-        isEmbedded = true;
-        isDamaged = false;
-        fontMatrixTransform = new AffineTransform();
-        codeToBytesMap = new HashMap<Integer,byte[]>();
+        this(doc, pfbIn, null);
     }
 
     /**
@@ -196,7 +188,7 @@ public class PDType1Font extends PDSimpleFont
     public PDType1Font(PDDocument doc, InputStream pfbIn, Encoding encoding) throws IOException
     {
         PDType1FontEmbedder embedder = new PDType1FontEmbedder(doc, dict, pfbIn, encoding);
-        this.encoding = encoding;
+        this.encoding = encoding == null ? embedder.getFontEncoding() : encoding;
         glyphList = embedder.getGlyphList();
         type1font = embedder.getType1Font();
         genericFont = embedder.getType1Font();
@@ -242,9 +234,13 @@ public class PDType1Font extends PDSimpleFont
 
                     // repair Length1 and Length2 if necessary
                     byte[] bytes = fontFile.toByteArray();
+                    if (bytes.length == 0)
+                    {
+                        throw new IOException("Font data unavailable");
+                    }
                     length1 = repairLength1(bytes, length1);
                     length2 = repairLength2(bytes, length1, length2);
-                    
+
                     if (bytes.length > 0 && (bytes[0] & 0xff) == PFB_START_MARKER)
                     {
                         // some bad files embed the entire PFB, see PDFBOX-2607
@@ -253,6 +249,11 @@ public class PDType1Font extends PDSimpleFont
                     else
                     {
                         // the PFB embedded as two segments back-to-back
+                        if (length1 < 0 || length1 > length1 + length2)
+                        {
+                            throw new IOException("Invalid length data, actual length: " +
+                                    bytes.length + ", /Length1: " + length1 + ", /Length2: " + length2);
+                        }
                         byte[] segment1 = Arrays.copyOfRange(bytes, 0, length1);
                         byte[] segment2 = Arrays.copyOfRange(bytes, length1, length1 + length2);
 
