@@ -506,6 +506,18 @@ public final class PDImageXObject extends PDXObject implements PDImage
         return image;
     }
 
+    @Override
+    public BufferedImage getRawImage() throws IOException
+    {
+        return getColorSpace().toRawImage(getRawRaster());
+    }
+
+    @Override
+    public WritableRaster getRawRaster() throws IOException
+    {
+        return SampledImageReader.getRawRaster(this);
+    }
+
     /**
      * Extract the matte color from a softmask.
      * 
@@ -523,6 +535,11 @@ public final class PDImageXObject extends PDXObject implements PDImage
             // see PDF specification 1.7, 11.6.5.3 Soft-Mask Images
             matte = ((COSArray) base).toFloatArray();
             // convert to RGB
+            if (matte.length < getColorSpace().getNumberOfComponents())
+            {
+                LOG.error("Image /Matte entry not long enough for colorspace, skipped");
+                return null;
+            }
             matte = getColorSpace().toRGB(matte);
         }
         return matte;
