@@ -195,6 +195,35 @@ public abstract class PDAnnotation implements COSObjectable
         dictionary.setItem(COSName.TYPE, COSName.ANNOT);
     }
 
+    /**
+     * {@inheritDoc}
+     */
+    @Override
+    public boolean equals (Object o) {
+        if (o == this)
+        {
+            return true;
+        }
+
+        if (!(o instanceof PDAnnotation))
+        {
+            return false;
+        }
+
+        COSDictionary toBeCompared = ((PDAnnotation) o).getCOSObject();
+        return toBeCompared.equals(getCOSObject());
+    }
+
+    /**
+     * {@inheritDoc}
+     */
+    @Override
+    public int hashCode()
+    {
+        return dictionary.hashCode();
+    }
+
+
     /**
      * The annotation rectangle, defining the location of the annotation on the page in default user space units. This
      * is usually required and should not return null on valid PDF documents. But where this is a parent form field with
@@ -795,9 +824,11 @@ public abstract class PDAnnotation implements COSObjectable
     }
 
     /**
-     * This will retrieve the corresponding page of this annotation.
-     * 
-     * @return the corresponding page
+     * This will retrieve the corresponding page of this annotation. See also
+     * <a href="https://stackoverflow.com/a/36894982/535646">this answer</a> about what to do if
+     * the page isn't available.
+     *
+     * @return The corresponding page or null if not available.
      */
     public PDPage getPage()
     {
