@@ -21,7 +21,6 @@ import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 import org.apache.pdfbox.cos.COSDictionary;
 import org.apache.pdfbox.cos.COSName;
-import org.apache.pdfbox.cos.COSStream;
 import org.apache.pdfbox.io.IOUtils;
 import org.apache.pdfbox.pdmodel.PDFormContentStream;
 import org.apache.pdfbox.pdmodel.PDResources;
@@ -130,8 +129,6 @@ public class PDHighlightAppearanceHandler extends PDAbstractAppearanceHandler
             r1.setBlendMode(BlendMode.MULTIPLY);
             cs.setGraphicsStateParameters(r0);
             cs.setGraphicsStateParameters(r1);
-            //TODO replace with document.getDocument().createCOSStream()
-            //     or call new PDFormXObject(document)
             PDFormXObject frm1 = new PDFormXObject(createCOSStream());
             PDFormXObject frm2 = new PDFormXObject(createCOSStream());
             frm1.setResources(new PDResources());
