@@ -25,7 +25,7 @@ import org.apache.pdfbox.cos.COSName;
 /**
  * A PDField factory.
  */
-final class PDFieldFactory
+public final class PDFieldFactory
 {
 
     private static final String FIELD_TYPE_TEXT = "Tx";
@@ -45,7 +45,7 @@ final class PDFieldFactory
      * @param parent the parent node of the node to be created 
      * @return the corresponding PDField instance
      */
-    static PDField createField(PDAcroForm form, COSDictionary field, PDNonTerminalField parent)
+    public static PDField createField(PDAcroForm form, COSDictionary field, PDNonTerminalField parent)
     {
         String fieldType = findFieldType(field);
         
