@@ -242,10 +242,7 @@ public class PDFTextStripper extends LegacyPDFStreamEngine
         {
             charactersByArticle.clear();
         }
-        if (characterListMapping != null)
-        {
-            characterListMapping.clear();
-        }
+        characterListMapping.clear();
     }
 
     /**
