@@ -45,6 +45,7 @@ import org.apache.pdfbox.pdmodel.graphics.image.PDImage;
 import org.apache.pdfbox.pdmodel.graphics.image.PDImageXObject;
 import org.apache.pdfbox.pdmodel.graphics.pattern.PDAbstractPattern;
 import org.apache.pdfbox.pdmodel.graphics.pattern.PDTilingPattern;
+import org.apache.pdfbox.pdmodel.graphics.state.PDExtendedGraphicsState;
 import org.apache.pdfbox.pdmodel.graphics.state.PDSoftMask;
 import org.apache.pdfbox.pdmodel.graphics.state.RenderingMode;
 import org.apache.pdfbox.tools.imageio.ImageIOUtil;
@@ -62,13 +63,15 @@ public final class ExtractImages
     private static final String PASSWORD = "-password";
     private static final String PREFIX = "-prefix";
     private static final String DIRECTJPEG = "-directJPEG";
+    private static final String NOCOLORCONVERT = "-noColorConvert";
 
     private static final List<String> JPEG = Arrays.asList(
             COSName.DCT_DECODE.getName(),
             COSName.DCT_DECODE_ABBREVIATION.getName());
 
-    private boolean directJPEG;
-    private String prefix;
+    private boolean useDirectJPEG;
+    private boolean noColorConvert;
+    private String filePrefix;
 
     private final Set<COSStream> seen = new HashSet<COSStream>();
     private int imageCounter = 1;
@@ -121,11 +124,15 @@ public final class ExtractImages
                     {
                         usage();
                     }
-                    prefix = args[i];
+                    filePrefix = args[i];
                 }
                 else if (args[i].equals(DIRECTJPEG))
                 {
-                    directJPEG = true;
+                    useDirectJPEG = true;
+                }
+                else if (args[i].equals(NOCOLORCONVERT))
+                {
+                    noColorConvert = true;
                 }
                 else
                 {
@@ -141,9 +148,9 @@ public final class ExtractImages
             }
             else
             {
-                if (prefix == null && pdfFile.length() >4)
+                if (filePrefix == null && pdfFile.length() > 4)
                 {
-                    prefix = pdfFile.substring(0, pdfFile.length() -4);
+                    filePrefix = pdfFile.substring(0, pdfFile.length() - 4);
                 }
 
                 extract(pdfFile, password);
@@ -160,8 +167,10 @@ public final class ExtractImages
                 + "\nOptions:\n"
                 + "  -password <password>   : Password to decrypt document\n"
                 + "  -prefix <image-prefix> : Image prefix (default to pdf name)\n"
-                + "  -directJPEG            : Forces the direct extraction of JPEG/JPX images "
+                + "  -directJPEG            : Forces the direct extraction of JPEG/JPX images \n"
                 + "                           regardless of colorspace or masking\n"
+                + "  -noColorConvert        : Images are extracted with their \n"
+                + "                           original colorspace if possible.\n"
                 + "  <inputfile>            : The PDF document to use\n";
         
         System.err.println(message);
@@ -207,9 +216,19 @@ public final class ExtractImages
             PDPage page = getPage();
             processPage(page);
             PDResources res = page.getResources();
+            if (res == null)
+            {
+                return;
+            }
             for (COSName name : res.getExtGStateNames())
             {
-                PDSoftMask softMask = res.getExtGState(name).getSoftMask();
+                PDExtendedGraphicsState extGState = res.getExtGState(name);
+                if (extGState == null)
+                {
+                    // can happen if key exists but no value 
+                    continue;
+                }
+                PDSoftMask softMask = extGState.getSoftMask();
                 if (softMask != null)
                 {
                     PDTransparencyGroup group = softMask.getGroup();
@@ -243,11 +262,11 @@ public final class ExtractImages
             }
 
             // save image
-            String name = prefix + "-" + imageCounter;
+            String name = filePrefix + "-" + imageCounter;
             imageCounter++;
 
             System.out.println("Writing image: " + name);
-            write2file(pdImage, name, directJPEG);
+            write2file(pdImage, name, useDirectJPEG, noColorConvert);
         }
 
         @Override
@@ -304,7 +323,6 @@ public final class ExtractImages
         protected void showGlyph(Matrix textRenderingMatrix, 
                                  PDFont font,
                                  int code,
-                                 String unicode,
                                  Vector displacement) throws IOException
         {
             RenderingMode renderingMode = getGraphicsState().getTextState().getRenderingMode();
@@ -355,53 +373,72 @@ public final class ExtractImages
                 }
             }
         }
-    }
 
-    private boolean hasMasks(PDImage pdImage) throws IOException
-    {
-        if (pdImage instanceof PDImageXObject)
+        /**
+         * Writes the image to a file with the filename prefix + an appropriate suffix, like
+         * "Image.jpg". The suffix is automatically set depending on the image compression in the
+         * PDF.
+         *
+         * @param pdImage the image.
+         * @param prefix the filename prefix.
+         * @param directJPEG if true, force saving JPEG/JPX streams as they are in the PDF file.
+         * @param noColorConvert if true, images are extracted with their original colorspace if
+         * possible.
+         * @throws IOException When something is wrong with the corresponding file.
+         */
+        private void write2file(PDImage pdImage, String prefix, boolean directJPEG,
+                boolean noColorConvert) throws IOException
         {
-            PDImageXObject ximg = (PDImageXObject) pdImage;
-            return ximg.getMask() != null || ximg.getSoftMask() != null;
-        }
-        return false;
-    }
-
-    /**
-     * Writes the image to a file with the filename prefix + an appropriate suffix, like "Image.jpg".
-     * The suffix is automatically set depending on the image compression in the PDF.
-     * @param pdImage the image.
-     * @param prefix the filename prefix.
-     * @param directJPEG if true, force saving JPEG/JPX streams as they are in the PDF file. 
-     * @throws IOException When something is wrong with the corresponding file.
-     */
-    private void write2file(PDImage pdImage, String prefix, boolean directJPEG) throws IOException
-    {
-        String suffix = pdImage.getSuffix();
-        if (suffix == null || "jb2".equals(suffix))
-        {
-            suffix = "png";
-        }
-        else if ("jpx".equals(suffix))
-        {
-            // use jp2 suffix for file because jpx not known by windows
-            suffix = "jp2";
-        }
-
-        FileOutputStream out = null;
-        try
-        {
-            out = new FileOutputStream(prefix + "." + suffix);
-            BufferedImage image = pdImage.getImage();
-            if (image != null)
+            String suffix = pdImage.getSuffix();
+            if (suffix == null || "jb2".equals(suffix))
             {
+                suffix = "png";
+            }
+            else if ("jpx".equals(suffix))
+            {
+                // use jp2 suffix for file because jpx not known by windows
+                suffix = "jp2";
+            }
+
+            if (hasMasks(pdImage))
+            {
+                // TIKA-3040, PDFBOX-4771: can't save ARGB as JPEG
+                suffix = "png";
+            }
+
+            FileOutputStream out = null;
+            try
+            {
+                if (noColorConvert)
+                {
+                    // We write the raw image if in any way possible.
+                    // But we have no alpha information here.
+                    BufferedImage image = pdImage.getRawImage();
+                    if (image != null)
+                    {
+                        int elements = image.getRaster().getNumDataElements();
+                        suffix = "png";
+                        if (elements > 3)
+                        {
+                            // More then 3 channels: Thats likely CMYK. We use tiff here,
+                            // but a TIFF codec must be in the class path for this to work.
+                            suffix = "tiff";
+                        }
+                        out = new FileOutputStream(prefix + "." + suffix);
+                        ImageIOUtil.writeImage(image, suffix, out);
+                        out.flush();
+                        out.close();
+                        return;
+                    }
+                }
+
+                out = new FileOutputStream(prefix + "." + suffix);
                 if ("jpg".equals(suffix))
                 {
                     String colorSpaceName = pdImage.getColorSpace().getName();
-                    if (directJPEG || 
-                            !hasMasks(pdImage) && 
-                                     (PDDeviceGray.INSTANCE.getName().equals(colorSpaceName) ||
-                                      PDDeviceRGB.INSTANCE.getName().equals(colorSpaceName)))
+                    if (directJPEG
+                            || (PDDeviceGray.INSTANCE.getName().equals(colorSpaceName)
+                            || PDDeviceRGB.INSTANCE.getName().equals(colorSpaceName)))
                     {
                         // RGB or Gray colorspace: get and write the unmodified JPEG stream
                         InputStream data = pdImage.createInputStream(JPEG);
@@ -411,16 +448,19 @@ public final class ExtractImages
                     else
                     {
                         // for CMYK and other "unusual" colorspaces, the JPEG will be converted
-                        ImageIOUtil.writeImage(image, suffix, out);
+                        BufferedImage image = pdImage.getImage();
+                        if (image != null)
+                        {
+                            ImageIOUtil.writeImage(image, suffix, out);
+                        }
                     }
                 }
                 else if ("jp2".equals(suffix))
                 {
                     String colorSpaceName = pdImage.getColorSpace().getName();
                     if (directJPEG || 
-                            !hasMasks(pdImage) && 
-                                     (PDDeviceGray.INSTANCE.getName().equals(colorSpaceName) ||
-                                      PDDeviceRGB.INSTANCE.getName().equals(colorSpaceName)))
+                        (PDDeviceGray.INSTANCE.getName().equals(colorSpaceName) ||
+                         PDDeviceRGB.INSTANCE.getName().equals(colorSpaceName)))
                     {
                         // RGB or Gray colorspace: get and write the unmodified JPEG2000 stream
                         InputStream data = pdImage.createInputStream(
@@ -429,24 +469,65 @@ public final class ExtractImages
                         IOUtils.closeQuietly(data);
                     }
                     else
-                    {                        
+                    {
                         // for CMYK and other "unusual" colorspaces, the image will be converted
-                        ImageIOUtil.writeImage(image, "jpeg2000", out);
+                        BufferedImage image = pdImage.getImage();
+                        if (image != null)
+                        {
+                            ImageIOUtil.writeImage(image, "jpeg2000", out);
+                        }
                     }
                 }
-                else 
+                else if ("tiff".equals(suffix) && pdImage.getColorSpace().equals(PDDeviceGray.INSTANCE))
                 {
-                    ImageIOUtil.writeImage(image, suffix, out);
+                    BufferedImage image = pdImage.getImage();
+                    if (image == null)
+                    {
+                        return;
+                    }
+                    // CCITT compressed images can have a different colorspace, but this one is B/W
+                    // This is a bitonal image, so copy to TYPE_BYTE_BINARY
+                    // so that a G4 compressed TIFF image is created by ImageIOUtil.writeImage()
+                    int w = image.getWidth();
+                    int h = image.getHeight();
+                    BufferedImage bitonalImage = new BufferedImage(w, h, BufferedImage.TYPE_BYTE_BINARY);
+                    // copy image the old fashioned way - ColorConvertOp is slower!
+                    for (int y = 0; y < h; y++)
+                    {
+                        for (int x = 0; x < w; x++)
+                        {
+                            bitonalImage.setRGB(x, y, image.getRGB(x, y));
+                        }
+                    }
+                    ImageIOUtil.writeImage(bitonalImage, suffix, out);
+                }
+                else
+                {
+                    BufferedImage image = pdImage.getImage();
+                    if (image != null)
+                    {
+                        ImageIOUtil.writeImage(image, suffix, out);
+                    }
+                }
+                out.flush();
+            }
+            finally
+            {
+                if (out != null)
+                {
+                    out.close();
                 }
             }
-            out.flush();
         }
-        finally
+
+        private boolean hasMasks(PDImage pdImage) throws IOException
         {
-            if (out != null)
+            if (pdImage instanceof PDImageXObject)
             {
-                out.close();
+                PDImageXObject ximg = (PDImageXObject) pdImage;
+                return ximg.getMask() != null || ximg.getSoftMask() != null;
             }
+            return false;
         }
     }
 }
