@@ -1115,9 +1115,10 @@ public class XMPSchema extends AbstractStructuredType
         {
             if (property instanceof ArrayProperty)
             {
-                List<String> retval = new ArrayList<String>();
                 ArrayProperty arrayProp = (ArrayProperty) property;
-                for (AbstractField child : arrayProp.getContainer().getAllProperties())
+                List<AbstractField> allProperties = arrayProp.getContainer().getAllProperties();
+                List<String> retval = new ArrayList<String>(allProperties.size());
+                for (AbstractField child : allProperties)
                 {
                     Attribute text = child.getAttribute(XmpConstants.LANG_NAME);
                     retval.add(text != null ? text.getValue() : XmpConstants.X_DEFAULT);
